.. APIS documentation master file, created by
   sphinx-quickstart on Tue Mar  7 13:24:27 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to APIS's documentation!
================================

.. include:: ../../README.md
   :parser: myst_parser.sphinx_

.. toctree::
   :maxdepth: 2
   :caption: Documentation:

   installation
   ontology
   configuration
   customization
   features
   development
   glossary

.. toctree::
   :maxdepth: 2
   :caption: Internals:

   genindex
   modindex
   Coverage <https://acdh-oeaw.github.io/apis-core-rdf/htmlcov/>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
